.. Copyright 2018 Peter K. G. Williams and collaborators. Licensed under the
   Creative Commons Attribution-ShareAlike 4.0 International License.

:py:mod:`neurosynchro`: the main module
=======================================

.. automodule:: neurosynchro
   :synopsis: train and use neural networks to approximate polarized synchrotron
              radiative transfer coefficients

.. currentmodule:: neurosynchro


.. _mappings:

Mappings
--------

.. autoclass:: Mapping
